==> apache-kyuubi-1.8.0-source.tgz: apache-kyuubi-1.8.0-source/externals/kyuubi-chat-engine/src/main/scala/org/apache/kyuubi/engine/chat/schema/SchemaHelper.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kyuubi.engine.chat.schema

import java.util.Collections

import org.apache.hive.service.rpc.thrift._

object SchemaHelper {

  def stringTTypeQualifiers: TTypeQualifiers = {
    val ret = new TTypeQualifiers()
    val qualifiers = Collections.emptyMap[String, TTypeQualifierValue]()
    ret.setQualifiers(qualifiers)
    ret
  }

  def stringTTypeDesc: TTypeDesc = {
    val typeEntry = new TPrimitiveTypeEntry(TTypeId.STRING_TYPE)
    typeEntry.setTypeQualifiers(stringTTypeQualifiers)
    val tTypeDesc = new TTypeDesc()
    tTypeDesc.addToTypes(TTypeEntry.primitiveEntry(typeEntry))
    tTypeDesc
  }

  def stringTColumnDesc(fieldName: String, pos: Int): TColumnDesc = {
    val tColumnDesc = new TColumnDesc()
    tColumnDesc.setColumnName(fieldName)
    tColumnDesc.setTypeDesc(stringTTypeDesc)
    tColumnDesc.setPosition(pos)
    tColumnDesc
  }

  def stringTTableSchema(fieldsName: String*): TTableSchema = {
    val tTableSchema = new TTableSchema()
    fieldsName.zipWithIndex.foreach { case (f, i) =>
      tTableSchema.addToColumns(stringTColumnDesc(f, i))
    }
    tTableSchema
  }
}

==> apache-kyuubi-1.11.0-source.tgz: apache-kyuubi-1.11.0-source/externals/kyuubi-chat-engine/src/main/scala/org/apache/kyuubi/engine/chat/schema/SchemaHelper.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kyuubi.engine.chat.schema

import java.util.Collections

import org.apache.kyuubi.shaded.hive.service.rpc.thrift._

object SchemaHelper {

  def stringTTypeQualifiers: TTypeQualifiers = {
    val ret = new TTypeQualifiers()
    val qualifiers = Collections.emptyMap[String, TTypeQualifierValue]()
    ret.setQualifiers(qualifiers)
    ret
  }

  def stringTTypeDesc: TTypeDesc = {
    val typeEntry = new TPrimitiveTypeEntry(TTypeId.STRING_TYPE)
    typeEntry.setTypeQualifiers(stringTTypeQualifiers)
    val tTypeDesc = new TTypeDesc()
    tTypeDesc.addToTypes(TTypeEntry.primitiveEntry(typeEntry))
    tTypeDesc
  }

  def stringTColumnDesc(fieldName: String, pos: Int): TColumnDesc = {
    val tColumnDesc = new TColumnDesc()
    tColumnDesc.setColumnName(fieldName)
    tColumnDesc.setTypeDesc(stringTTypeDesc)
    tColumnDesc.setPosition(pos)
    tColumnDesc
  }

  def stringTTableSchema(fieldsName: String*): TTableSchema = {
    val tTableSchema = new TTableSchema()
    fieldsName.zipWithIndex.foreach { case (f, i) =>
      tTableSchema.addToColumns(stringTColumnDesc(f, i))
    }
    tTableSchema
  }
}
